#!/usr/bin/perl
#
# By: Jason "ZeroDiVide" Orcutt
#
########################################
# This script requires perl 5 support
########################################

use Getopt::Long;
use lib './lib';
use ApacheKit;

# Unbuffer stderr, stdout
select( STDERR ); $| = 1;
select( STDOUT ); $| = 1;

if ( $< != 0 ) {
   die <<"RUN_ME_AS_ROOT";
Please log in as root for this to work. This is
 needed for the installation steps where things are
 copied into their destinations.
RUN_ME_AS_ROOT
}

$ORACLE_AVAILABLE    = 0;

$MOD_PERL_MEDIA_AVAILABLE  = 0;
$PHP_MEDIA_AVAILABLE       = 0;
$APACHE_MEDIA_AVAILABLE    = 0;
$IMAP_MEDIA_AVAILABLE      = 0;

$FREEBSD_PLAT        = 0;
$REDHAT_7_PLAT       = 0;
$REDHAT_6_PLAT       = 0;
$REDHAT_5_PLAT       = 0;
$SOLARIS_GCC_PLAT    = 0;

$BUILD_OPENSSL       = 0;
$BUILD_MOD_SSL       = 0;
$BUILD_MOD_PERL      = 0;
$BUILD_IMAP          = 0;
$BUILD_PHP3          = 0;
$BUILD_PHP4          = 0;

$IMAP_DIR            = '';
$MYSQL_DIR           = '';
$ORACLE_HOME         = '';

$OPENSSL_DIR         = '';
$APACHE_DIR          = '';
$ORACLE_HOME            = $ENV{ "ORACLE_HOME" };
$APACHE_DIR             = '/usr/local/apache';

my $result = GetOptions(
   'redhat-7',          \$REDHAT_7_PLAT,
   'redhat-6',          \$REDHAT_6_PLAT,
   'redhat-5',          \$REDHAT_5_PLAT,
   'solaris-gcc',       \$SOLARIS_GCC_PLAT,
   'freebsd',           \$FREEBSD_PLAT,
   # TODO: Fixme -- ApacheKit.pm doesn't respect these
   #'imap=s',            \$IMAP_DIR,
   #'with-imap',         \$IMAP_AVAILABLE,
   #'with-oracle',       \$ORACLE_AVAILABLE,
   #'oracle-home=s',     \$ORACLE_HOME,
   #'build-wget',        \$BUILD_WGET,
   'openssl-dir=s',     \$OPENSSL_DIR,
   'apache-dir=s',      \$APACHE_DIR,

   'build-imap',        \$BUILD_IMAP,
   'build-php3',        \$BUILD_PHP3,
   'build-php4',        \$BUILD_PHP4,
   'build-mod-perl',    \$BUILD_MOD_PERL,
   'build-mod-ssl',     \$BUILD_MOD_SSL,
   'build-openssl',     \$BUILD_OPENSSL,

);

$apache_kit = ApacheKit->new();

if ( ! $REDHAT_5_PLAT   && ! $REDHAT_6_PLAT   && ! $REDHAT_7_PLAT   && 
     ! $SOLARIS_GCC_PLAT && ! $FREEBSD_PLAT ) {
   $apache_kit->display_commandline_options( 'Please provide a OS' );
   exit();
}

if ( ! $BUILD_PHP3  && ! $BUILD_PHP4 && ! $BUILD_MOD_PERL && ! $BUILD_OPENSSL && ! $BUILD_MOD_SSL ) {
   $apache_kit->display_commandline_options( 'Please choose the modules for build' );
   exit();
}

# Temporaryily not needed - gawd this is a slow build
if ( $BUILD_MOD_SSL ) {
   $BUILD_OPENSSL = 1;
}

$apache_kit->{ 'redhat_7' }      = $REDHAT_7_PLAT;
$apache_kit->{ 'redhat_6' }      = $REDHAT_6_PLAT;
$apache_kit->{ 'redhat_5' }      = $REDHAT_5_PLAT;
$apache_kit->{ 'solaris_gcc' }   = $SOLARIS_GCC_PLAT;
$apache_kit->{ 'freebsd' }       = $FREEBSD_PLAT;

$apache_kit->{ 'build_openssl' }       = $BUILD_OPENSSL;
$apache_kit->{ 'build_imap' }          = $BUILD_IMAP;
$apache_kit->{ 'build_php3' }          = $BUILD_PHP3;
$apache_kit->{ 'build_php4' }          = $BUILD_PHP4;
$apache_kit->{ 'build_mod_perl' }      = $BUILD_MOD_PERL;
$apache_kit->{ 'build_mod_ssl' }       = $BUILD_MOD_SSL;

$apache_kit->{ 'openssl_dir' }   = $OPENSSL_DIR;
$apache_kit->{ 'apache_dir' }    = $APACHE_DIR;

$apache_kit->run();

print "Apache build complete\n";

exit();
