package ApacheKit::Apache;

use ApacheKit::Output;
use ApacheKit::Base;
use ApacheKit::Media;
use ApacheKit::ModSsl;
use ApacheKit::Openssl;

@ISA = qw(ApacheKit::Base);

use strict;

sub _init {
   my $self = shift;

   $self->{ 'output' }              = ApacheKit::Output->new();
   $self->{ 'media' }               = ApacheKit::Media->new();
# CHANGE THIS:
   $self->{ 'apache_version' }      = '1.3.26';
   $self->{ 'apache_src' }          = 'apache_' . $self->{ 'apache_version' };
   $self->{ 'apache_compressed' }   = 'apache_' . $self->{ 'apache_version' } . '.tar.gz';

   $self->{ 'apache_log' } = 'apache_build_log.log';
# CHANGE THIS:   
   $self->{ 'apache_dir' } = '/usr/local/opt/apache-1.3.26';

   $self->{ 'mod_ssl' } = ApacheKit::ModSsl->new();
   $self->{ 'openssl' } = ApacheKit::Openssl->new();

}

sub build {
   my $self = shift;

   $self->{ 'media' }->copy_defaults( $self );

   my $apache_available = $self->{ 'media' }->uncompress(
         $self->{ 'apache_compressed' },
         $self->{ 'apache_src' }
   );

   if ( $apache_available == 0 ) {
      # The apache isn't available...
      die
      "Apache didn't uncompress correctly\n" .
      "Things to check for -\n" .
      "compressed/" . $self->{ 'apache_compressed' } . " is the source archive\n" .
      $self->{ 'apache_src' } . " is the destination directory\n" .
      "\n";
   }

   if ( $self->{ 'build_mod_ssl' } == 1 ) {
      $self->{'mod_ssl'}->copy_defaults($self);
      $self->{'mod_ssl'}->build( 
         '../' . $self->{ 'apache_src' }, 
         '../' . $self->{ 'openssl' }->{'openssl_src'}
      );
   }

   my @configure_command = ();

   if ( $self->{ 'build_mod_ssl' } == 1 ) {
      # Okie picky brat mod_ssl gets a global var
      push( @configure_command, 
         'SSL_BASE="../' . 
            $self->{'openssl'}->{'openssl_src'} . 
         "\""
      );

   }

   push( @configure_command, './configure' );
   push( @configure_command, '--prefix=' . $self->{ 'apache_dir' } );

   my @tmp = ( 'rewrite', 'so' );

   if ( $self->{ 'build_mod_ssl' } == 1 ) {
      push( @tmp, 'ssl' );
   }

   foreach my $module ( @tmp ) {
      push( @configure_command, '--enable-module=' . $module );
   }

   $self->build_command(
      'Apache configure',
      join( ' ', @configure_command )
   );

   $self->build_command(
      'Compiling apache',
      'make'
   );

   if ( $self->{ 'build_mod_ssl' } == 1 ) {
      #$self->build_command( 'Installing dummy SSL cert', 'make certificate TYPE=dummy' );
      $self->build_command( 'Installing testing SSL cert', 'make certificate TYPE=dummy' );
   }

   $self->build_command(
      'Installing apache',
      'make install'
   );

   if ( ! -f $self->{ 'apache_dir' } . '/bin/apxs' ) {
      die "The apxs script is not available, either something failed\n" .
          "during the apache install or this is a non apxs supported\n" .
          "platform\n";
   }

}

sub build_command {
   my $self             = shift;
   my $command_prompt   = shift;
   my $command_to_run   = shift;

   my $date = localtime();

   my @command = (
      'cd ' . $self->{ 'apache_src' } . ' ; ',
      $command_to_run,
      '>> ' . $self->{ 'apache_log' },
      '2>&1'
   );

   open( LOG_FILE, '>> ' . 
      $self->{ 'apache_src' } . '/' . $self->{ 'apache_log' } 
   ) or die "Unable to open apache build log file : $!\n";

   select( LOG_FILE ); $| = 1;

   print "\n";
   print "*" x 70 . "\n";
   print "$date - Build command\n";
   print "$date - " . join( ' ', @command ) . "\n\n";
   print "*" x 70 . "\n";
   print "\n";

   close( LOG_FILE );

   select( STDOUT ); $| = 1;

   $self->{ 'output' }->start( $command_prompt );
   system( join( ' ', @command ) );
   $self->{ 'output' }->stop( 'Done' );

}

sub add_dir_index_file {
   my $self = shift;
   my $file_name = shift;

   open( CONF_FILE, $self->{ 'apache_dir' } . '/conf/httpd.conf' );
   open( TMP_FILE, '> ' . $self->{ 'apache_dir' } . '/conf/httpd.conf.bak' );
   while( my $input_line = <CONF_FILE> ) {
      my ( $line, $comment ) = split( /\#/, $input_line );
      $line =~ s/\n//;
      $line =~ s/\r//;
      if ( $line eq '' ) {       print TMP_FILE $input_line; next; }
      if ( $line !~ /[a-z]/i ) { print TMP_FILE $input_line; next; }

      if ( $line =~ /DirectoryIndex (.*)$/ ) {
         my $dir_indexes = $1;
         my @dir_files = split( ' ', $dir_indexes );
         foreach my $dir_file ( @dir_files ) {
            if ( $file_name eq $dir_file ) {
            } else {
               $dir_indexes .= ' ' . $file_name;
            }
         }
         print TMP_FILE 'DirectoryIndex ' . $dir_indexes . "\n";
         next;
      }
      print TMP_FILE $input_line;
      #print "L: " . $line . "\n";
      #print "C: " . $comment . "\n";

   }
   close( CONF_FILE );
   close( TMP_FILE );

   open( CONF_FILE, '> ' . $self->{ 'apache_dir' } . '/conf/httpd.conf' );
   open( TMP_FILE, $self->{ 'apache_dir' } . '/conf/httpd.conf.bak' );
   while( <TMP_FILE> ) { print CONF_FILE $_; }
   close( TMP_FILE );
   close( CONF_FILE );

}

sub activate_addtype {
   my $self = shift;
   my $type_to_activate = shift;
   my $file_ext         = shift;

   my $type_activated = 0;

   open( CONF_FILE, $self->{ 'apache_dir' } . '/conf/httpd.conf' );
   while( my $input_line = <CONF_FILE> ) {
      my ( $line, $comment ) = split( /\#/, $input_line );
      $line =~ s/\n//;
      $line =~ s/\r//;
      if ( $line eq '' ) { next; }
      if ( $line !~ /[a-z]/i ) { next; }

      if ( $line =~ /AddType $type_to_activate $file_ext/ ) {
         $type_activated = 1;
      }

      #print "L: " . $line . "\n";
      #print "C: " . $comment . "\n";

   }
   close( CONF_FILE );

   if ( $type_activated == 1 ) {
      return 1;
   }

   $self->{ 'output' }->start( 'Activating type' );
   open( CONF_FILE, $self->{ 'apache_dir' } . '/conf/httpd.conf' );
   open( TMP_FILE, '> ' . $self->{ 'apache_dir' } . '/conf/httpd.conf.bak' );

   while( my $input_line = <CONF_FILE> ) {
      if ( $input_line =~ /\#/ ) {
         my ( $line, $comment ) = split( /\#/, $input_line );
         $line =~ s/\n//g;
         $line =~ s/\r//g;
         if ( $comment eq '' ) { 
            print TMP_FILE $input_line;
            next;
         }
         if ( $comment !~ /[a-z]/i ) {
            print TMP_FILE $input_line;
            next;
         }
         #print "L: " . $line . "\n";
         if ( $comment =~ /AddType $type_to_activate $file_ext/ ) {
            #print "C: " . $comment . "\n";
            #print "Unactivated type\n";
            print TMP_FILE $line . 'AddType ' . $type_to_activate . ' ' . $file_ext . "\n";
         } else {
            print TMP_FILE $input_line;
         }
      } else {
         print TMP_FILE $input_line;
      }
   }
   close( CONF_FILE );
   close( TMP_FILE );

   open( CONF_FILE, '> ' . $self->{ 'apache_dir' } . '/conf/httpd.conf' );
   open( TMP_FILE, $self->{ 'apache_dir' } . '/conf/httpd.conf.bak' );
   while( <TMP_FILE> ) { print CONF_FILE $_; }
   close( TMP_FILE );
   close( CONF_FILE );

   $self->{ 'output' }->stop( 'Done' );

}

1;
