package ApacheKit::Base;

sub new {
   my $proto         = shift;
   my $self;
   my $class = ref( $proto ) || $proto;
   $self = {};
   bless ( $self, $class );
   $self->_init( @_ );
   $self->init_defaults();
   return $self;
}

sub _init {
}

sub DESTROY {
}

sub dump_structure {
   my $self = shift;

   print ref( $self ) . "\n";

   while( my ( $key, $value ) = each( %$self ) ) {
      printf "%-30s %s\n", $key, (defined $value ? $value : '' );
   }

}

sub init_defaults {
   my $self = shift;

   $self->{ 'cp_command' }       = '';
   $self->{ 'mkdir_command' }    = '';
   $self->{ 'gunzip_command' }   = '';
   $self->{ 'tar_command' }      = '';
   $self->{ 'perl_command' }     = '';

   # TODO: need rsaref detection support for openssl us citizens
   #$self->{ 'rsaref_available' } = 0;

   $self->{ 'aspell_available' } = 0;
   $self->{ 'ldap_available' }   = 0;
   $self->{ 'imap_available' }   = 0;
   $self->{ 'mysql_available' }  = 0;
   $self->{ 'gd_available' }     = 0;
   $self->{ 'postgres_available' } = 0;
   $self->{ 'oracle_available' } = 0;
   $self->{ 'oracle_home' }      = 0;

   $self->{ 'redhat_7' }         = 0;
   $self->{ 'redhat_6' }         = 0;
   $self->{ 'redhat_5' }         = 0;
   $self->{ 'solaris_gcc' }      = 0;
   $self->{ 'freebsd' }          = 0;

   $self->{ 'build_openssl' }    = 0;
   $self->{ 'build_imap' }       = 0;
   $self->{ 'build_php3' }       = 0;
   $self->{ 'build_php4' }       = 0;
   $self->{ 'build_mod_perl' }   = 0;
   $self->{ 'build_mod_ssl' }    = 0;
# Change these:
   $self->{ 'openssl_dir' }      = '/usr/local/opt/openssl-0.9.6c';
   $self->{ 'apache_dir' }       = '/usr/local/opt/apache-1.3.26';

}

sub copy_defaults {
   my $self = shift;
   my $src  = shift;

   $self->{ 'cp_command' }       = $src->{ 'cp_command' };
   $self->{ 'mkdir_command' }    = $src->{ 'mkdir_command' };
   $self->{ 'gunzip_command' }   = $src->{ 'gunzip_command' };
   $self->{ 'tar_command' }      = $src->{ 'tar_command' };
   $self->{ 'perl_command' }     = $src->{ 'perl_command' };

   $self->{ 'imap_available' }   = $src->{ 'imap_available' };
   $self->{ 'aspell_available' } = $src->{ 'aspell_available' };
   $self->{ 'ldap_available' }   = $src->{ 'ldap_available' };
   $self->{ 'mysql_available' }  = $src->{ 'mysql_available' };
   $self->{ 'gd_available' }     = $src->{ 'gd_available' };
   $self->{ 'postgres_available' } = $src->{ 'postgres_available' };
   $self->{ 'oracle_available' } = $src->{ 'oracle_available' };
   $self->{ 'oracle_home' }      = $src->{ 'oracle_home' };

   $self->{ 'redhat_6' }         = $src->{ 'redhat_6' };
   $self->{ 'redhat_5' }         = $src->{ 'redhat_5' };
   $self->{ 'solaris_gcc' }      = $src->{ 'solaris_gcc' };
   $self->{ 'freebsd' }          = $src->{ 'freebsd' };

   $self->{ 'build_openssl' }    = $src->{ 'build_openssl' };
   $self->{ 'build_imap' }       = $src->{ 'build_imap' };
   $self->{ 'build_php3' }       = $src->{ 'build_php3' };
   $self->{ 'build_php4' }       = $src->{ 'build_php4' };
   $self->{ 'build_mod_perl' }   = $src->{ 'build_mod_perl' };
   $self->{ 'build_mod_ssl' }    = $src->{ 'build_mod_ssl' };

   $self->{ 'openssl_dir' }      = $src->{ 'openssl_dir' };
   $self->{ 'apache_dir' }       = $src->{ 'apache_dir' };

}

1;
