package ApacheKit::Imap;

use ApacheKit::Base;
use ApacheKit::Output;
use ApacheKit::Media;

@ISA = qw(ApacheKit::Base);

use strict;

sub _init {
   my $self = shift;

   $self->{ 'output' }              = ApacheKit::Output->new();
   $self->{ 'media' }               = ApacheKit::Media->new();
#Change this:
   $self->{ 'imap_version' }        = '2001a';
   # This fixes a really stupid packaging bug
   $self->{ 'imap_src' }            = 'imap-' . $self->{ 'imap_version' };
   $self->{ 'imap_compressed' }     = 'imap-' . $self->{ 'imap_version' } . '.tar.gz';
   $self->{ 'imap_log' } = 'imap_build_log.log';
}

sub build {
   my $self    = shift;

   $self->{ 'media' }->copy_defaults( $self );

   my $imap_available = $self->{ 'media' }->uncompress(
      $self->{ 'imap_compressed' },
      $self->{ 'imap_src' }
   );

   if ( $imap_available == 0 ) {
      # Php3 isn't available
      die
      "Imap didn't uncompress correctly\n" .
      "Things to check for -\n" .
      "compressed/" . $self->{ 'imap_compressed' } . " is the source archive\n" .
      $self->{ 'imap_src' } . " is the destination folder\n" .
      "\n";
   }

   my $plat = '';

   if ( $self->{ 'redhat_6' } || $self->{ 'redhat_5' } ) {
      $plat = 'slx';
   }

   if ( $self->{ 'solaris_gcc' } ) {
      $plat = 'gso';
   }

   if ( $self->{ 'freebsd' } ) {
      $plat = 'bsf';
   }

   $self->build_command(
      'Building imap',
      'make ' . $plat
   );
# Change these:
   if ( ! -d '/usr/local/opt/imap-2001a' ) {
      system( $self->{ 'mkdir_command' } . ' /usr/local/opt/imap-2001a' );
   }
   if ( ! -d '/usr/local/opt/imap-2001a/lib' ) {
      system( $self->{ 'mkdir_command' } . ' /usr/local/opt/imap-2001a/lib' );
   }
   if ( ! -d '/usr/local/opt/imap-2001a/include/' ) {
      system( $self->{ 'mkdir_command' } . ' /usr/local/opt/imap-2001a/include' );
   }
   my %copy_hash = (
      'c-client/c-client.a'  => '/usr/local/opt/imap-2001a/lib',
      'c-client/c-client.a'  => '/usr/local/opt/imap-2001a/lib/libc-client.a',
      'c-client/rfc822.h'    => '/usr/local/opt/imap-2001a/include',
      'c-client/mail.h'      => '/usr/local/opt/imap-2001a/include',
      'c-client/linkage.h'   => '/usr/local/opt/imap-2001a/include',
   );

   foreach my $src_file ( keys %copy_hash ) {
      $self->build_command( 
         'Installing ' . $src_file,
         $self->{ 'cp_command' } . ' ' .
            $src_file . ' ' .
            $copy_hash{ $src_file }
      );
   }

}

sub build_command {
   my $self             = shift;
   my $command_prompt   = shift;
   my $command_to_run   = shift;

   my $date = localtime();

   my @command = (
      'cd ' . $self->{ 'imap_src' } . ' ; ',
      $command_to_run,
      '>> ' . $self->{ 'imap_log' },
      '2>&1'
   );

   open( LOG_FILE, '>> ' . 
      $self->{ 'imap_src' } . '/' . $self->{ 'imap_log' } 
   ) or die "Unable to open imap build log file : $!\n";

   select( LOG_FILE ); $| = 1;

   print "\n";
   print "*" x 70 . "\n";
   print "$date - Build command\n";
   print "$date - " . join( ' ', @command ) . "\n\n";
   print "*" x 70 . "\n";
   print "\n";

   close( LOG_FILE );

   select( STDOUT ); $| = 1;

   $self->{ 'output' }->start( $command_prompt );
   system( join( ' ', @command ) );
   $self->{ 'output' }->stop( 'Done' );

}

1;
