package ApacheKit::Media;

use ApacheKit::Base;
use ApacheKit::Output;
@ISA = qw(ApacheKit::Base);

use strict;

sub _init {
   my $self = shift;
   $self->{ 'output' } = ApacheKit::Output->new();
}

sub uncompress {
   my $self = shift;
   my $media_name       = shift;
   my $output_dir_name  = shift;

   if ( ! -d $output_dir_name ) {
      # Uncompress and such
      if ( ! -f 'compressed/' . $media_name ) {
         die
         "FATAL: The source tarball of : compressed/$media_name is not present\n";
      }

      my @uncompress_command = (
         $self->{ 'gunzip_command' } . ' -c compressed/' . $media_name .
         '|',
         $self->{ 'tar_command' } . ' xvf - ',
         '> uncompress_' . $media_name . '.log',
         '2>&1'
      );

      $self->{ 'output' }->start( 'Uncompressing ' . $media_name );
      system( join( ' ', @uncompress_command ) );
      $self->{ 'output' }->stop( 'Done' );

      if ( -d $output_dir_name ) {
         return 1;
      }

      return 0;

   } else {
      # Make clean
      my @make_clean_command = (
         'cd ' . $output_dir_name,
         ';',
         'make clean',
         '> /dev/null',
         '2> /dev/null'
      );

      my $config_cache = $output_dir_name . '/config.cache';
      my $apache_log   = $output_dir_name . '/apache_build_log.log';
      my $php_log      = $output_dir_name . '/php_build_log.log';
      my $mod_perl_log = $output_dir_name . '/mod_perl_build_log.log';

      $self->{ 'output' }->start( 'Make clean ' . $output_dir_name );
      system( join( ' ', @make_clean_command ) );
      $self->{ 'output' }->stop( 'Done' );

      $self->_remove_file( 'Configure cache',      $config_cache );
      $self->_remove_file( 'Apache build log',     $apache_log );
      $self->_remove_file( 'Php build log',        $php_log );
      $self->_remove_file( 'Mod_perl build log',   $mod_perl_log );

      return 1;

   }

   return 0;

}

sub _remove_file {
   my $self = shift;
   my $caption = shift;
   my $file    = shift;

   if ( -f $file ) {
      $self->{ 'output' }->start( $caption );
      unlink( $file );
      $self->{ 'output' }->stop( 'Done' );
   }

}

1;
