package ApacheKit::ModPerl;

use ApacheKit::Base;
use ApacheKit::Output;
use ApacheKit::Media;

@ISA = qw(ApacheKit::Base);

use strict;

sub _init {
   my $self = shift;

   $self->{ 'output' }              = ApacheKit::Output->new();
   $self->{ 'media' }               = ApacheKit::Media->new();

   $self->{ 'mod_perl_version' }    = '1.27';
   $self->{ 'mod_perl_src' }        = 'mod_perl-' . $self->{ 'mod_perl_version' };
   $self->{ 'mod_perl_compressed' } = 'mod_perl-' . $self->{ 'mod_perl_version' } . '.tar.gz';
   $self->{ 'apache_dir' }          = '/usr/local/apache';
   $self->{ 'mod_perl_log' }        = 'mod_perl_build_log.log';

}

sub build {
   my $self    = shift;

   $self->{ 'media' }->copy_defaults( $self );

   my $mod_perl_available = $self->{ 'media' }->uncompress(
      $self->{ 'mod_perl_compressed' },
      $self->{ 'mod_perl_src' }
   );

   if ( $mod_perl_available == 0 ) {
      # Mod_perl isn't available
      die
      "Mod perl didn't uncompress correctly\n" .
      "Things to check for -\n" .
      "compressed/" . $self->{ 'mod_perl_compressed' } . " is the source archive\n" .
      $self->{ 'mod_perl_src' } . " is the destination folder\n" .
      "\n";
   }

   my @configure_command = (
      'perl',
      'Makefile.PL',
      'USE_APXS=1',
      'WITH_APXS=' . $self->{ 'apache_dir' } . '/bin/apxs',
      'EVERYTHING=1'
   );

   $self->build_command(
      'Configuring mod perl',
      join( ' ', @configure_command )
   );

   $self->build_command(
      'Building mod perl',
      'make'
   );

   $self->build_command(
      'Installing mod perl',
      'make install'
   );

}

sub check_for_configure {
   my $self = shift;

   if ( $self->{ 'mod_perl_src' } . '/configure' ) {
      $self->build_command(
         'Creating the configure script',
         './buildconf'
      );
   }

}

sub build_command {
   my $self             = shift;
   my $command_prompt   = shift;
   my $command_to_run   = shift;

   my $date = localtime();

   my @command = (
      'cd ' . $self->{ 'mod_perl_src' } . ' ; ',
      $command_to_run,
      '>> ' . $self->{ 'mod_perl_log' },
      '2>&1'
   );

   open( LOG_FILE, '>> ' . 
      $self->{ 'mod_perl_src' } . '/' . $self->{ 'mod_perl_log' } 
   ) or die "Unable to open apache build log file : $!\n";

   select( LOG_FILE ); $| = 1;

   print "\n";
   print "*" x 70 . "\n";
   print "$date - Build command\n";
   print "$date - " . join( ' ', @command ) . "\n\n";
   print "*" x 70 . "\n";
   print "\n";

   close( LOG_FILE );

   select( STDOUT ); $| = 1;

   $self->{ 'output' }->start( $command_prompt );
   system( join( ' ', @command ) );
   $self->{ 'output' }->stop( 'Done' );

}

1;
