package ApacheKit::ModSsl;

use ApacheKit::Base;
use ApacheKit::Output;
use ApacheKit::Media;

@ISA = qw(ApacheKit::Base);

use strict;

sub _init {
   my $self = shift;

   $self->{ 'output' }              = ApacheKit::Output->new();
   $self->{ 'media' }               = ApacheKit::Media->new();
# Change this:
   $self->{ 'modssl_version' }        = '2.8.10-1.3.26';
   # This fixes a really stupid packaging bug
   $self->{ 'modssl_src' }            = 'mod_ssl-' . $self->{ 'modssl_version' };
   $self->{ 'modssl_compressed' }     = 'mod_ssl-' . $self->{ 'modssl_version' } . '.tar.gz';
   $self->{ 'modssl_log' } = 'modssl_build_log.log';
}

sub build {
   my $self          = shift;
   my $apache_dir    = shift;
   my $ssl_dir       = shift;

   $self->{ 'media' }->copy_defaults( $self );

   my $modssl_available = $self->{ 'media' }->uncompress(
      $self->{ 'modssl_compressed' },
      $self->{ 'modssl_src' }
   );

   if ( $modssl_available == 0 ) {
      # ModSsl isn't available
      die
      "ModSsl didn't uncompress correctly\n" .
      "Things to check for -\n" .
      "compressed/" . $self->{ 'modssl_compressed' } . " is the source archive\n" .
      $self->{ 'modssl_src' } . " is the destination folder\n" .
      "\n";
   }

   my @command = (
      './configure',
      '--with-apache=' . $apache_dir,
      '--with-ssl=' . $ssl_dir,
      '--prefix=' . $self->{'apache_dir'},
   );

   $self->build_command(
      'Configuring mod_ssl',
      join( ' ', @command )
   );

}

sub build_command {
   my $self             = shift;
   my $command_prompt   = shift;
   my $command_to_run   = shift;

   my $date = localtime();

   my @command = (
      'cd ' . $self->{ 'modssl_src' } . ' ; ',
      $command_to_run,
      '>> ' . $self->{ 'modssl_log' },
      '2>&1'
   );

   open( LOG_FILE, '>> ' . 
      $self->{ 'modssl_src' } . '/' . $self->{ 'modssl_log' } 
   ) or die "Unable to open modssl build log file : $!\n";

   select( LOG_FILE ); $| = 1;

   print "\n";
   print "*" x 70 . "\n";
   print "$date - Build command\n";
   print "$date - " . join( ' ', @command ) . "\n\n";
   print "*" x 70 . "\n";
   print "\n";

   close( LOG_FILE );

   select( STDOUT ); $| = 1;

   $self->{ 'output' }->start( $command_prompt );
   system( join( ' ', @command ) );
   $self->{ 'output' }->stop( 'Done' );

}

1;
