package ApacheKit::Openssl;

use ApacheKit::Base;
use ApacheKit::Output;
use ApacheKit::Media;

@ISA = qw(ApacheKit::Base);

use strict;

sub _init {
   my $self = shift;

   $self->{ 'output' }              = ApacheKit::Output->new();
   $self->{ 'media' }               = ApacheKit::Media->new();
# Change this:
   $self->{ 'openssl_version' }        = '0.9.6c';
   # This fixes a really stupid packaging bug
   $self->{ 'openssl_src' }            = 'openssl-' . $self->{ 'openssl_version' };
   $self->{ 'openssl_compressed' }     = 'openssl-' . $self->{ 'openssl_version' } . '.tar.gz';
   $self->{ 'openssl_log' } = 'openssl_build_log.log';
}

sub build {
   my $self    = shift;

   $self->{ 'media' }->copy_defaults( $self );

   my $openssl_available = $self->{ 'media' }->uncompress(
      $self->{ 'openssl_compressed' },
      $self->{ 'openssl_src' }
   );

   if ( $openssl_available == 0 ) {
      # Openssl isn't available
      die
      "Openssl didn't uncompress correctly\n" .
      "Things to check for -\n" .
      "compressed/" . $self->{ 'openssl_compressed' } . " is the source archive\n" .
      $self->{ 'openssl_src' } . " is the destination folder\n" .
      "\n";
   }

   my @command = (
      'configure',
#      '--prefix=' . $self->{ 'openssl_dir' },
      '--prefix=/usr/local/opt/ossl-php'
      # TODO: Rsaref
      #-L`pwd`/../rsaref-2.0/local/rsaref -fPIC
   );

   $self->build_command(
      'Configuring openssl',
      join( ' ', @command )
   );

   $self->build_command(
      'Building openssl',
      'make'
   );

   $self->build_command(
      'Making the tests',
      'make test'
   );

   $self->build_command(
      'Installing openssl',
      'make install'
   );

}

sub build_command {
   my $self             = shift;
   my $command_prompt   = shift;
   my $command_to_run   = shift;

   my $date = localtime();

   my @command = (
      'cd ' . $self->{ 'openssl_src' } . ' ; ',
      $command_to_run,
      '>> ' . $self->{ 'openssl_log' },
      '2>&1'
   );

   open( LOG_FILE, '>> ' . 
      $self->{ 'openssl_src' } . '/' . $self->{ 'openssl_log' } 
   ) or die "Unable to open openssl build log file : $!\n";

   select( LOG_FILE ); $| = 1;

   print "\n";
   print "*" x 70 . "\n";
   print "$date - Build command\n";
   print "$date - " . join( ' ', @command ) . "\n\n";
   print "*" x 70 . "\n";
   print "\n";

   close( LOG_FILE );

   select( STDOUT ); $| = 1;

   $self->{ 'output' }->start( $command_prompt );
   system( join( ' ', @command ) );
   $self->{ 'output' }->stop( 'Done' );

}

1;
