package ApacheKit::Php3;

use ApacheKit::Base;
use ApacheKit::Output;
use ApacheKit::Media;

@ISA = qw(ApacheKit::Base);

use strict;

sub _init {
   my $self = shift;

   $self->{ 'output' }              = ApacheKit::Output->new();
   $self->{ 'media' }               = ApacheKit::Media->new();

   $self->{ 'php3_version' }        = '3.0.18';
   $self->{ 'php3_src' }            = 'php-' . $self->{ 'php3_version' };
   $self->{ 'php3_compressed' }     = 'php-' . $self->{ 'php3_version' } . '.tar.gz';
   $self->{ 'apache_dir' }          = '/usr/local/apache';
   $self->{ 'php3_log' }            = 'php3_build_log.log';

}

sub build {
   my $self    = shift;

   $self->{ 'media' }->copy_defaults( $self );

   my $php3_available = $self->{ 'media' }->uncompress(
      $self->{ 'php3_compressed' },
      $self->{ 'php3_src' }
   );

   if ( $php3_available == 0 ) {
      # Php3 isn't available
      die
      "Php3 didn't uncompress correctly\n" .
      "Things to check for -\n" .
      "compressed/" . $self->{ 'php3_compressed' } . " is the source archive\n" .
      $self->{ 'php3_src' } . " is the destination folder\n" .
      "\n";
   }

   my @configure_command = (
      './configure',
      '--enable-debug=no',
      '--enable-memory-limit',
      '--with-apxs=' . $self->{ 'apache_dir' } . '/bin/apxs',
      '--enable-versioning'
   );

   if ( $self->{'aspell_available'} == 1 ) {
      push( @configure_command, '--with-aspell' );
   }

   if ( $self->{ 'ldap_available' } == 1 ) {
      push( @configure_command, '--with-ldap' );
   }

   if ( $self->{ 'mysql_available' } == 1 ) {
      push( @configure_command, '--with-mysql' );
   }

   if ( $self->{ 'gd_available' } == 1 ) {
      push( @configure_command, '--with-gd' );
   }

   if ( $self->{ 'postgres_available' } == 1 ) {
      if ( $self->{ 'redhat_6' } ) {
         push( @configure_command, '--with-pgsql=/usr' );
      } else {
         push( @configure_command, '--with-pgsql' );
      }
   }

   if ( $self->{ 'imap_available' } == 1 ) {
      if ( $self->{ 'build_imap' } ) {
         push( @configure_command, '--with-imap=/usr/local/' );
      } else {
         push( @configure_command, '--with-imap' );
      }
   }

   if ( $self->{ 'oracle_available' } == 1 ) {
      push( @configure_command, '--with-oracle=' . $self->{ 'oracle_home' } );
   }

   $self->check_for_configure();

   $self->build_command(
      'Configuring php3',
      join( ' ', @configure_command )
   );

   $self->build_command(
      'Building php3',
      'make'
   );

   $self->build_command(
      'Installing php3',
      'make install'
   );


   if ( ! -f '/usr/local/lib/php.ini' ) {
      $self->build_command(
         'Copying php default configuation',
         $self->{ 'cp_command' } . ' ' . 
         'php.ini-dist /usr/local/lib/php.ini'
      );
   }

}

sub check_for_configure {
   my $self = shift;

   if ( $self->{ 'php3_src' } . '/configure' ) {
      $self->build_command(
         'Creating the configure script',
         './buildconf'
      );
   }

}

sub build_command {
   my $self             = shift;
   my $command_prompt   = shift;
   my $command_to_run   = shift;

   my $date = localtime();

   my @command = (
      'cd ' . $self->{ 'php3_src' } . ' ; ',
      $command_to_run,
      '>> ' . $self->{ 'php3_log' },
      '2>&1'
   );

   open( LOG_FILE, '>> ' . 
      $self->{ 'php3_src' } . '/' . $self->{ 'php3_log' } 
   ) or die "Unable to open apache build log file : $!\n";

   select( LOG_FILE ); $| = 1;

   print "\n";
   print "*" x 70 . "\n";
   print "$date - Build command\n";
   print "$date - " . join( ' ', @command ) . "\n\n";
   print "*" x 70 . "\n";
   print "\n";

   close( LOG_FILE );

   select( STDOUT ); $| = 1;

   $self->{ 'output' }->start( $command_prompt );
   system( join( ' ', @command ) );
   $self->{ 'output' }->stop( 'Done' );

}

1;
