package ApacheKit::Php4;

use ApacheKit::Base;
use ApacheKit::Output;
use ApacheKit::Media;

@ISA = qw(ApacheKit::Base);

use strict;

sub _init {
   my $self = shift;

   $self->{ 'output' }              = ApacheKit::Output->new();
   $self->{ 'media' }               = ApacheKit::Media->new();
# Change this:
   $self->{ 'php4_version' }        = '4.2.1';
   $self->{ 'php4_src' }            = 'php-' . $self->{ 'php4_version' };
   $self->{ 'php4_compressed' }     = 'php-' . $self->{ 'php4_version' } . '.tar.gz';
# Change this:   
   $self->{ 'apache_dir' }          = '/usr/local/opt/apache-1.3.26';
   $self->{ 'php4_log' }            = 'php4_build_log.log';

}

sub build {
   my $self    = shift;

   $self->{ 'media' }->copy_defaults( $self );

   my $php4_available = $self->{ 'media' }->uncompress(
      $self->{ 'php4_compressed' },
      $self->{ 'php4_src' }
   );

   if ( $php4_available == 0 ) {
      # Php4 isn't available
      die
      "Php4 didn't uncompress correctly\n" .
      "Things to check for -\n" .
      "compressed/" . $self->{ 'php4_compressed' } . " is the source archive\n" .
      $self->{ 'php4_src' } . " is the destination folder\n" .
      "\n";
   }

   my @configure_command = (
      './configure',
      '--enable-debug=no',
#Change these:      
      '--prefix=/usr/local/opt/php-4.2.1',
      ' --with-config-file-path=/usr/local/opt/php-4.2.1',
#      '--enable-memory-limit',
      '--with-apxs=' . $self->{ 'apache_dir' } . '/bin/apxs',
      '--enable-shmop',
      '--enable-sysvshm',
      ' --with-imap-ssl',
      '--enable-versioning',
      '--with-gd',
      '--enable-gd-native-tt',
      '--with-png-dir=/usr/local',
      '--with-zlib-dir=/usr/local',
      ' --with-freetype-dir=/usr/local',
      ' --with-t1lib',
      '--enable-track-vars',
      '--enable-trans-sid',
#      ' --with-gettext',
      ' --with-jpeg-dir=/usr'
   );

   if ( $self->{'aspell_available'} == 1 ) {
      push( @configure_command, '--with-aspell' );
   }

   if ( $self->{ 'ldap_available' } == 1 ) {
      push( @configure_command, '--with-ldap' );
   }

   if ( $self->{ 'mysql_available' } == 1 ) {
      push( @configure_command, '--with-mysql' );
   }

   if ( $self->{ 'gd_available' } == 1 ) {
      push( @configure_command, '--with-gd' );
   }

   if ( $self->{ 'postgres_available' } == 1 ) {
      if ( $self->{ 'redhat_6' } ) {
         push( @configure_command, '--with-pgsql=/usr' );
      } else {
         push( @configure_command, '--with-pgsql' );
      }
   }

   if ( $self->{ 'imap_available' } == 1 ) {
      if ( $self->{ 'build_imap' } ) {
# Change this:         
	 push( @configure_command, '--with-imap=/usr/local/opt/imap-2001a' );
      } else {
         if ( $self->{ 'redhat_7' } ) {
            push( @configure_command, '--with-imap' );
            push( @configure_command, '--with-imap-ssl' );
         } else {
            push( @configure_command, '--with-imap' );
         }
      }
   }

   if ( $self->{ 'oracle_available' } == 1 ) {
      push( @configure_command, '--with-oracle=' . $self->{ 'oracle_home' } );
      push( @configure_command, '--with-oci8' );
   }

   $self->check_for_configure();

   $self->build_command(
      'Configuring php4',
      join( ' ', @configure_command )
   );

   $self->build_command(
      'Building php4',
      'make'
   );

   $self->build_command(
      'Installing php4',
      'make install'
   );

# Change this:   
   if ( ! -f '/usr/local/opt/php-4.2.1/php.ini' ) {
      $self->build_command(
         'Copying php default configuation',
         $self->{ 'cp_command' } . ' ' . 
         'php.ini-dist /usr/local/opt/php-4.2.1/php.ini'
      );
   }

}

sub check_for_configure {
   my $self = shift;

   if ( $self->{ 'php4_src' } . '/configure' ) {
      $self->build_command(
         'Creating the configure script',
         './buildconf'
      );
   }

}

sub build_command {
   my $self             = shift;
   my $command_prompt   = shift;
   my $command_to_run   = shift;

   my $date = localtime();

   my @command = (
      'cd ' . $self->{ 'php4_src' } . ' ; ',
      $command_to_run,
      '>> ' . $self->{ 'php4_log' },
      '2>&1'
   );

   open( LOG_FILE, '>> ' . 
      $self->{ 'php4_src' } . '/' . $self->{ 'php4_log' } 
   ) or die "Unable to open apache build log file : $!\n";

   select( LOG_FILE ); $| = 1;

   print "\n";
   print "*" x 70 . "\n";
   print "$date - Build command\n";
   print "$date - " . join( ' ', @command ) . "\n\n";
   print "*" x 70 . "\n";
   print "\n";

   close( LOG_FILE );

   select( STDOUT ); $| = 1;

   $self->{ 'output' }->start( $command_prompt );
   system( join( ' ', @command ) );
   $self->{ 'output' }->stop( 'Done' );

}

1;
